macro_rules! kprint {
($($tt:tt)*) => { ... };
}Expand description
Prints formatted text directly to standard kernel console output (via C printf).
macro_rules! kprint {
($($tt:tt)*) => { ... };
}Prints formatted text directly to standard kernel console output (via C printf).