macro_rules! kprintln {
($($tt:tt)*) => { ... };
}Expand description
Prints formatted text followed by a newline to standard kernel console output (via C printf).
macro_rules! kprintln {
($($tt:tt)*) => { ... };
}Prints formatted text followed by a newline to standard kernel console output (via C printf).